function [d, c] = choltridLU(a,b)
%
% [d, c] = choltridLU(a,b)
% Computes the Choleksy factorization of a symmetric tridiagonal matrix
%        diag(a)+diag(b,-1)+diag(b,1)
% (the matrix is assumed to be positive definite)
% where
% L = diag(c,-1)+diag(d)
% and
% U = diag(d) + diag(c,1)
%
% Input:  a = diagonal             [dimension     nx1]
%         b = sub-super-diagonal   [dimension (n-1)x1]
%
% Output: d = diagonal of matrix L
%         c = subdiagonal of matrix L
%
n = length(a);
d  = zeros(n,1);
c = zeros(n-1,1);
d(1) = sqrt(a(1));
c(1) = b(1)/d(1);
for i = 2:n-1
    d(i) = sqrt(a(i) - c(i-1)*c(i-1));
    c(i) = b(i)/d(i);
end
d(n) = sqrt(a(n) - c(n-1)*c(n-1));