function x = choltridSolve(d,c,f)
%
% Solves (LL^T)x = f, where L and L^T are the Cholesky factors of
% the tridiagonal matrix: diag(a)+diag(b,-1)+diag(b,1)
%
n = length(d);
x  = zeros(n,1);
%
% Forward substitution to solve Ly = f
x(1) = f(1)/d(1);
for i = 2:n
    x(i) = (f(i) - c(i-1)*x(i-1))/d(i);
end
%
% Back substitution to solve (L^T)x = y
x(n) = x(n)/d(n);
for i = n-1:-1:1
    x(i) = (x(i) - c(i)*x(i+1))/d(i);
end